Method: YARD::CodeObjects::Proxy#type

Defined in:
lib/yard/code_objects/proxy.rb

#typeSymbol

Returns the type of the proxy. If it cannot be resolved at the time of the call, it will either return the inferred proxy type (see #type=) or :proxy

Returns:

  • (Symbol)

    the Proxy’s type

See Also:



151
152
153
# File 'lib/yard/code_objects/proxy.rb', line 151

def type
  to_obj ? to_obj.type : @type || :proxy
end