Method: YARD::CodeObjects::MethodObject#explicit

Defined in:
lib/yard/code_objects/method_object.rb

#explicitBoolean

Whether the object is explicitly defined in source or whether it was inferred by a handler. For instance, attribute methods are generally inferred and therefore not explicitly defined in source.

Returns:

  • (Boolean)

    whether the object is explicitly defined in source.



18
19
20
# File 'lib/yard/code_objects/method_object.rb', line 18

def explicit
  @explicit
end