Class: YARD::Tags::ScopeDirective
- Defined in:
- lib/yard/tags/directives.rb
Overview
Modifies the current parsing scope (class or instance). If this directive is defined on a docstring attached to an object definition, it is applied only to that object. Otherwise, it applies the scope to all future objects in the namespace.
Parser callbacks collapse
Constructor Details
This class inherits a constructor from YARD::Tags::Directive
Instance Method Details
#call ⇒ Object
586 587 588 589 590 591 592 593 594 595 596 |
# File 'lib/yard/tags/directives.rb', line 586 def call if %w(class instance module).include?(tag.text) if object.is_a?(CodeObjects::MethodObject) object.scope = tag.text.to_sym elsif handler && !inside_directive? handler.scope = tag.text.to_sym else parser.state.scope = tag.text.to_sym end end end |