Method: YARD::CodeObjects::Base#title
- Defined in:
- lib/yard/code_objects/base.rb
#title ⇒ String
Note:
Override this method if your object has a special title that does not match the #path attribute value. This title will be used when linking or displaying the object.
Returns the display title for an object.
468 469 470 |
# File 'lib/yard/code_objects/base.rb', line 468 def title path end |