Method: YARD::CodeObjects::NamespaceMapper#default_separator
- Defined in:
- lib/yard/code_objects/namespace_mapper.rb
#default_separator(value = nil) ⇒ Object
Gets or sets the default separator value to use when no separator for the namespace can be determined.
51 52 53 54 55 56 57 |
# File 'lib/yard/code_objects/namespace_mapper.rb', line 51 def default_separator(value = nil) if value NamespaceMapper.default_separator = Regexp.quote value else NamespaceMapper.default_separator end end |