Class: YARD::Docstring
Overview
A documentation string, or “docstring” for short, encapsulates the comments and metadata, or “tags”, of an object. Meta-data is expressed in the form @tag VALUE, where VALUE can span over multiple lines as long as they are indented. The following @example tag shows how tags can be indented:
# @example My example
# a = "hello world"
# a.reverse
# @version 1.0
Tags can be nested in a documentation string, though the Tags::Tag itself is responsible for parsing the inner tags.
Constant Summary collapse
- META_MATCH =
Deprecated.
Matches a tag at the start of a comment line
DocstringParser::META_MATCH
Instance Attribute Summary collapse
-
#all ⇒ String
readonly
The raw documentation (including raw tag text).
-
#hash_flag ⇒ Boolean
Whether the docstring was started with “##”.
-
#line_range ⇒ Range
Line range in the #object‘s file where the docstring was parsed from.
-
#object ⇒ CodeObjects::Base
The object that owns the docstring.
-
#ref_tags ⇒ Array<Tags::RefTag>
readonly
The list of reference tags.
Creating a Docstring Object collapse
-
.new!(text, tags = [], object = nil, raw_data = nil) ⇒ Object
Creates a new docstring without performing any parsing through a DocstringParser.
-
#+(other) ⇒ Docstring
Adds another Docstring, copying over tags.
-
#dup ⇒ Docstring
Deep-copies a docstring.
-
#initialize(content = '', object = nil) ⇒ Docstring
constructor
Creates a new docstring with the raw contents attached to an optional object.
-
#replace(content, parse = true) ⇒ Object
(also: #all=)
Replaces the docstring with new raw content.
Creating and Accessing Meta-data collapse
-
#add_tag(*tags) ⇒ void
Adds a tag or reftag object to the tag list.
-
#blank?(only_visible_tags = true) ⇒ Boolean
Returns true if the docstring has no content that is visible to a template.
-
#delete_tag_if {|tag| ... } ⇒ void
Deletes all tags where the block returns true.
-
#delete_tags(name) ⇒ void
Delete all tags with
name. -
#has_tag?(name) ⇒ Boolean
Returns true if at least one tag by the name
namewas declared. -
#tag(name) ⇒ Tags::Tag
Convenience method to return the first tag object in the list of tag objects of that name.
-
#tags(name = nil) ⇒ Array<Tags::Tag>
Returns a list of tags specified by
nameor all tags ifnameis not specified.
Instance Method Summary collapse
- #line ⇒ Fixnum?
-
#summary ⇒ String
Gets the first line of a docstring to the period or the first paragraph.
-
#to_raw ⇒ String
Reformats and returns a raw representation of the tag data using the current tag and docstring data, not the original text.
Constructor Details
#initialize(content = '', object = nil) ⇒ Docstring
To properly parse directives with proper parser context within handlers, you should not use this method to create a Docstring. Instead, use YARD::DocstringParser, which takes a handler object that can pass parser state onto directives. If a Docstring is created with this method, directives do not have access to any parser state, and may not function as expected.
Creates a new docstring with the raw contents attached to an optional object. Parsing will be done by the YARD::DocstringParser class.
73 74 75 76 77 78 79 |
# File 'lib/yard/docstring.rb', line 73 def initialize(content = '', object = nil) @object = object @summary = nil @hash_flag = false self.all = content end |
Instance Attribute Details
#all ⇒ String (readonly)
Returns the raw documentation (including raw tag text).
26 27 28 |
# File 'lib/yard/docstring.rb', line 26 def all @all end |
#hash_flag ⇒ Boolean
Returns whether the docstring was started with “##”.
29 30 31 |
# File 'lib/yard/docstring.rb', line 29 def hash_flag @hash_flag end |
#line_range ⇒ Range
Returns line range in the #object‘s file where the docstring was parsed from.
23 24 25 |
# File 'lib/yard/docstring.rb', line 23 def line_range @line_range end |
#object ⇒ CodeObjects::Base
Returns the object that owns the docstring.
20 21 22 |
# File 'lib/yard/docstring.rb', line 20 def object @object end |
#ref_tags ⇒ Array<Tags::RefTag> (readonly)
Returns the list of reference tags.
17 18 19 |
# File 'lib/yard/docstring.rb', line 17 def end |
Class Method Details
.new!(text, tags = [], object = nil, raw_data = nil) ⇒ Object
Creates a new docstring without performing any parsing through a YARD::DocstringParser. This method is called by DocstringParser when creating the new docstring object.
48 49 50 51 52 53 54 55 |
# File 'lib/yard/docstring.rb', line 48 def self.new!(text, = [], object = nil, raw_data = nil) docstring = allocate docstring.replace(text, false) docstring.object = object docstring.add_tag(*) docstring.instance_variable_set("@all", raw_data) if raw_data docstring end |
Instance Method Details
#+(other) ⇒ Docstring
Adds another YARD::Docstring, copying over tags.
86 87 88 89 90 91 92 93 |
# File 'lib/yard/docstring.rb', line 86 def +(other) case other when Docstring Docstring.new([all, other.all].join("\n"), object) else super end end |
#add_tag(*tags) ⇒ void
This method returns an undefined value.
Adds a tag or reftag object to the tag list. If you want to parse tag data based on the Tags::DefaultFactory tag factory, use YARD::DocstringParser instead.
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/yard/docstring.rb', line 188 def add_tag(*) .each_with_index do |tag, i| case tag when Tags::Tag tag.object = object << tag when Tags::RefTag, Tags::RefTagList << tag else raise ArgumentError, "expected Tag or RefTag, got #{tag.class} (at index #{i})" end end end |
#blank?(only_visible_tags = true) ⇒ Boolean
Returns true if the docstring has no content that is visible to a template.
256 257 258 259 260 261 262 |
# File 'lib/yard/docstring.rb', line 256 def blank?( = true) if empty? && !.any? {|tag| Tags::Library..include?(tag.tag_name.to_sym) } else empty? && .empty? && .empty? end end |
#delete_tag_if {|tag| ... } ⇒ void
This method returns an undefined value.
Deletes all tags where the block returns true
246 247 248 249 |
# File 'lib/yard/docstring.rb', line 246 def delete_tag_if(&block) .delete_if(&block) .delete_if(&block) end |
#delete_tags(name) ⇒ void
This method returns an undefined value.
Delete all tags with name
237 238 239 |
# File 'lib/yard/docstring.rb', line 237 def (name) delete_tag_if {|tag| tag.tag_name.to_s == name.to_s } end |
#dup ⇒ Docstring
This method creates a new docstring with new tag lists, but does not create new individual tags. Modifying the tag objects will still affect the original tags.
Deep-copies a docstring
112 113 114 115 116 117 118 119 |
# File 'lib/yard/docstring.rb', line 112 def dup obj = super %w(all summary tags ref_tags).each do |name| val = instance_variable_get("@#{name}") obj.instance_variable_set("@#{name}", val ? val.dup : nil) end obj end |
#has_tag?(name) ⇒ Boolean
Returns true if at least one tag by the name name was declared
229 230 231 |
# File 'lib/yard/docstring.rb', line 229 def has_tag?(name) .any? {|tag| tag.tag_name.to_s == name.to_s } end |
#line ⇒ Fixnum?
125 126 127 |
# File 'lib/yard/docstring.rb', line 125 def line line_range ? line_range.first : nil end |
#replace(content, parse = true) ⇒ Object Also known as: all=
Replaces the docstring with new raw content. Called by #all=.
97 98 99 100 101 102 |
# File 'lib/yard/docstring.rb', line 97 def replace(content, parse = true) content = content.join("\n") if content.is_a?(Array) , = [], [] @all = content super(parse ? parse_comments(content) : content) end |
#summary ⇒ String
Gets the first line of a docstring to the period or the first paragraph.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/yard/docstring.rb', line 131 def summary return @summary if @summary open_parens = ['{', '(', '['] close_parens = ['}', ')', ']'] num_parens = 0 idx = length.times do |index| case self[index, 1] when ".", "\r", "\n" next_char = self[index + 1, 1].to_s if num_parens == 0 && next_char =~ /^\s*$/ break index - 1 end when "{", "(", "[" num_parens += 1 when "}", ")", "]" num_parens -= 1 end end @summary = self[0..idx] @summary += '.' unless @summary.empty? @summary end |
#tag(name) ⇒ Tags::Tag
Convenience method to return the first tag object in the list of tag objects of that name
211 212 213 |
# File 'lib/yard/docstring.rb', line 211 def tag(name) .find {|tag| tag.tag_name.to_s == name.to_s } end |
#tags(name = nil) ⇒ Array<Tags::Tag>
Returns a list of tags specified by name or all tags if name is not specified.
219 220 221 222 223 |
# File 'lib/yard/docstring.rb', line 219 def (name = nil) list = + return list unless name list.select {|tag| tag.tag_name.to_s == name.to_s } end |
#to_raw ⇒ String
Add Tags::Tag#to_raw and refactor
Reformats and returns a raw representation of the tag data using the current tag and docstring data, not the original text.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/yard/docstring.rb', line 160 def to_raw tag_data = .sort_by {|t| t.tag_name }.map do |tag| case tag when Tags::OverloadTag tag_text = "@#{tag.tag_name} #{tag.signature}\n" unless tag.docstring.blank? tag_text += "\n" + tag.docstring.all.gsub(/\r?\n/, "\n ") end else tag_text = '@' + tag.tag_name tag_text += ' [' + tag.types.join(', ') + ']' if tag.types tag_text += ' ' + tag.name.to_s if tag.name tag_text += "\n " if tag.name && tag.text tag_text += ' ' + tag.text.strip.gsub(/\n/, "\n ") if tag.text end tag_text end [strip, tag_data.join("\n")].reject {|l| l.empty? }.compact.join("\n") end |